@@ -18,8 +18,7 @@
 #ifndef ACTIVE_COMIC_MODEL_H
 #define ACTIVE_COMIC_MODEL_H
 
-#include <QtGui/QtGui>
-#include <QtCore/QtCore>
+#include <QStandardItemModel>
 
 class ActiveComicModel : public QStandardItemModel
 {
@@ -34,7 +33,9 @@ public:
         ComicHighlightRole = Qt::UserRole+4
     };
 
-    ActiveComicModel(QObject *parent = 0);
+    explicit ActiveComicModel(QObject *parent = nullptr);
+
+    QHash<int, QByteArray> roleNames() const override;
 
     void addComic(const QString &key, const QString &title, const QString &iconPath, bool highlight = true);
 
@@ -46,4 +47,4 @@ Q_SIGNALS:
     void countChanged();
 };
 
-#endif
\ No newline at end of file
+#endif
