@@ -17,8 +17,8 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
  ***************************************************************************/
 
-#ifndef COMIC_TYPE_H
-#define COMIC_TYPE_H
+#ifndef COMICINFO_H
+#define COMICINFO_H
 
 class KConfigGroup;
 class QString;
@@ -40,7 +40,7 @@ class SavingDir
          * @param config the config that should be used to retrieve
          * the saving directory and to store it to in case of changes
          */
-        SavingDir(const KConfigGroup &config);
+        explicit SavingDir(const KConfigGroup &config);
 
         ~SavingDir();
 
