@@ -3,10 +3,10 @@
  *   Copyright  2008 by Anne-Marie Mahfouf <annma@kde.org>
  *   Copyright 2016 Weng Xuetian <wengxt@gmail.com>
  *
- *   This program is free software; you can redistribute it and/or modify  
- *   it under the terms of the GNU General Public License as published by  
- *   the Free Software Foundation; either version 2 of the License, or     
- *   (at your option) any later version.   
+ *   This program is free software; you can redistribute it and/or modify
+ *   it under the terms of the GNU General Public License as published by
+ *   the Free Software Foundation; either version 2 of the License, or
+ *   (at your option) any later version.
  *
  *   This program is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -60,8 +60,7 @@ class NOAAProvider : public PotdProvider
         QImage image() const override;
 
     private:
-        void firstPageRequestFinished(KJob *job);
-        void secondPageRequestFinished(KJob *job);
+        void pageRequestFinished(KJob *job);
         void imageRequestFinished(KJob *job);
 
    private:
