@@ -22,6 +22,7 @@
 #include <QDate>
 #include <QFile>
 #include <QFileInfo>
+#include <QRegularExpression>
 #include <QTimer>
 #include <QThreadPool>
 #include <QDebug>
@@ -102,17 +103,11 @@ bool PotdEngine::updateSource( const QString &identifier, bool loadCachedAlways
         qDebug() << "invalid provider: " << parts[ 0 ];
         return false;
     }
-
+    
     QVariantList args;
-    args << providerName;
-    if ( parts.count() > 1 ) {
-        const QDate date = QDate::fromString( parts[ 1 ], Qt::ISODate );
-        if ( !date.isValid() ) {
-            qDebug() << "invalid date:" << parts[1];
-            return false;
-        }
 
-        args << date;
+    for (int i = 0; i < parts.count(); i++) {
+        args << parts[i];
     }
 
     auto factory = KPluginLoader(mFactories[ providerName ].fileName()).factory();
@@ -179,6 +174,8 @@ void PotdEngine::checkDayChanged()
 {
     SourceDict dict = containerDict();
     QHashIterator<QString, Plasma::DataContainer*> it( dict );
+    QRegularExpression re(QLatin1String(":\\d{4}-\\d{2}-\\d{2}"));
+
     while ( it.hasNext() ) {
         it.next();
 
@@ -186,7 +183,9 @@ void PotdEngine::checkDayChanged()
             continue;
         }
 
-        if ( !it.key().contains(QLatin1Char(':')) ) {
+        // Check if the identifier contains ISO date string, like 2019-01-09.
+        // If so, don't update the picture. Otherwise, update the picture.
+        if ( !re.match(it.key()).hasMatch() ) {
             const QString path = CachedProvider::identifierToPath( it.key() );
             if ( !QFile::exists(path) ) {
                 updateSourceEvent( it.key() );
